/*******************************************************************************
 * SiReNe software version 1.0
 * Copyright © 2018-2020, INRIA, CNRS, Université de Lorraine. All rights reserved.
 *
 * Authors : N. AZEVEDO CARVALHO, S. CONTASSOT-VIVIER, L. BUHRY and D. MARTINEZ
 * Version : 1.0
 * Years   : 2018-2020
 *
 * License : GNU General Public License, version 2
 *
 * This  program is  free  software; you  can  redistribute it  and/or
 * modify it  under the  terms of  the GNU  General Public  License as
 * published by the Free Software  Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT  ANY  WARRANTY;  without   even  the  implied  warranty  of
 * MERCHANTABILITY or FITNESS  FOR A PARTICULAR PURPOSE.   See the GNU
 * General Public License for more details.
 *
 ******************************************************************************/
/*!
 * @file 
 * @brief Bézier curve interpolation for spike detection
 ******************************************************************************/

#ifndef BEZIER2_INTERPOLATION_H
#define BEZIER2_INTERPOLATION_H

/*!*****************************************************************************
 * @brief Description of a point in the 2D plane
 ******************************************************************************/
typedef struct
{
  double x, y; ///< 2D Coordinates
} Point2D;

/*!*****************************************************************************
 * @brief Computes the extremum of the Bézier curve defined by (P1, P2, P3)
 * along the specified dimension
 *
 * Quadratic Bézier curve B(t) = (1-t)².P1 + 2.(1-t).P2 + t².P3,  t in [0,1]
 * where points Pi(xi, yi) are defined by 2D coordinates x and y.
 *
 * @param Axis     The coordinate to be maximized ('x' or 'y')
 * @param P1,P2,P3 The three control points of the Bézier curve 
 *
 * @result 2D point corresponding to the extremum along the specified Axis 
 ******************************************************************************/
extern Point2D BezierMax(char Axis, Point2D *P1, Point2D *P2, Point2D *P3);

#endif
