/*******************************************************************************
 * SiReNe software version 1.0
 * Copyright © 2018-2020, INRIA, CNRS, Université de Lorraine. All rights reserved.
 *
 * Authors : N. AZEVEDO CARVALHO, S. CONTASSOT-VIVIER, L. BUHRY and D. MARTINEZ
 * Version : 1.0
 * Years   : 2018-2020
 *
 * Authors : W. RAPHA, E. HUGUES, D. MARTINEZ and Y. BONIFACE
 * Version : 0.1
 * Years   : 2002-2009
 *
 * License : GNU General Public License, version 2
 *
 * This  program is  free  software; you  can  redistribute it  and/or
 * modify it  under the  terms of  the GNU  General Public  License as
 * published by the Free Software  Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT  ANY  WARRANTY;  without   even  the  implied  warranty  of
 * MERCHANTABILITY or FITNESS  FOR A PARTICULAR PURPOSE.   See the GNU
 * General Public License for more details.
 *
 ******************************************************************************/
/*!
 * @file 
 * @brief Display functions for neurons and models
 ******************************************************************************/

#ifndef DISPLAYS_H
#define DISPLAYS_H

#include "Sirene.h"

/*!*****************************************************************************
 * @brief Display of a neural model
 *
 * Displayed information:
 *   - Neural model number
 *   - Number of neurons in the model 
 *   - Local neuron numbering
 *   - Number of variables
 *   - Number of parameters
 *   - Parameters of the model
 *   - Spike threshold
 *
 * @param Simulation Structure where all simulation information is stored
 * @param ModelNum   Neural model number
 * @param Output     Output stream of the display
 ******************************************************************************/
extern void NeuralModelPrint(Simul *Simulation, int ModelNum, FILE *Output);

/*!*****************************************************************************
 * @brief Display of a synaptic model between two neural models
 *
 * Displayed information:
 *   - Synapse model from neuron model SrcModel to neuron model DstModel
 *   - Number of variables 
 *   - Number of parameters
 *   - Parameters
 *
 * @param Simulation Structure where all simulation information is stored
 * @param SrcModel   Source neural model
 * @param DstModel   Destination neural model
 * @param Output     Output stream of the display
 ******************************************************************************/
extern void SynapseModelPrint(Simul *Simulation, int SrcModel, int DstModel, FILE *Output);

/*!*****************************************************************************
 * @brief Display of neuron NeuronNum in model ModelNum
 *
 * Displayed information:
 *   - Number of parameters 
 *   - Parameters 
 *   - Number of variables 
 *   - Initial values 
 *   - Potential index in the Variables array 
 *   - Number of spikes
 *   - Last spike time
 *
 * @param Simulation Structure where all simulation information is stored
 * @param ModelNum   Neural model number
 * @param NeuronNum  Neuron number
 * @param Output     Output stream of the display
 ******************************************************************************/
extern void NeuronPrint(Simul *Simulation, int ModelNum, int NeuronNum, FILE *Output);

/*!*****************************************************************************
 * @brief Display of the execution times of different subparts of the program
 *
 * Display of execution times for the specified thread or all threads if value is negative.
 *
 * @param Simulation Structure where all simulation information is stored
 * @param Thread     Thread number (all threads are displayed for negative values)
 * @param Output     Output stream of the display
 ******************************************************************************/
extern void PrintTimes(Simul *Simulation, int Thread, FILE *Output);

#endif
