/*******************************************************************************
 * SiReNe software version 1.0
 * Copyright © 2018-2020, INRIA, CNRS, Université de Lorraine. All rights reserved.
 *
 * Authors : N. AZEVEDO CARVALHO, S. CONTASSOT-VIVIER, L. BUHRY and D. MARTINEZ
 * Version : 1.0
 * Years   : 2018-2020
 *
 * Authors : W. RAPHA, E. HUGUES, D. MARTINEZ and Y. BONIFACE
 * Version : 0.1
 * Years   : 2002-2009
 *
 * License : GNU General Public License, version 2
 *
 * This  program is  free  software; you  can  redistribute it  and/or
 * modify it  under the  terms of  the GNU  General Public  License as
 * published by the Free Software  Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT  ANY  WARRANTY;  without   even  the  implied  warranty  of
 * MERCHANTABILITY or FITNESS  FOR A PARTICULAR PURPOSE.   See the GNU
 * General Public License for more details.
 *
 ******************************************************************************/
/*!
 * @file 
 * @brief Different input currents of the neurons
 ******************************************************************************/

#ifndef INPUTCURRENTS_H
#define INPUTCURRENTS_H

/*!*****************************************************************************
 * @brief Constant input current
 *
 * @param Simulation Structure where all simulation information is stored
 * @param ModelNum   Neural model number
 * @param NeuronNum  Neuron number
 * @param t          Current time t 
 *
 * @result Value of the input current of neuron NeuronNum in model ModelNum at time t
 ******************************************************************************/
extern double ConstantInputCurrent(Simul *Simulation, int ModelNum, int NeuronNum, double t);

/*!*****************************************************************************
 * @brief Constant input current with symmetric uniform noise
 * optionally multiplied by a specific amplitude noise
 *
 * @param Simulation Structure where all simulation information is stored
 * @param ModelNum   Neural model number
 * @param NeuronNum  Neuron number
 * @param t          Current time t 
 *
 * @result Value of the input current of neuron NeuronNum in model ModelNum at time t
 ******************************************************************************/
extern double InputCurrentWithNoise(Simul *Simulation, int ModelNum, int NeuronNum, double t);

/*!*****************************************************************************
 * @brief Stepwise input current
 *
 * @param Simulation Structure where all simulation information is stored
 * @param ModelNum   Neural model number
 * @param NeuronNum  Neuron number
 * @param t          Current time t 
 *
 * @result Value of the input current of neuron NeuronNum in model ModelNum at time t
 ******************************************************************************/
extern double StepwiseInputCurrent(Simul *Simulation, int ModelNum, int NeuronNum, double t);

/*!*****************************************************************************
 * @brief Stepwise input current with a specific amplitude noise
 * and an optional symmetric uniform noise
 *
 * @param Simulation Structure where all simulation information is stored
 * @param ModelNum   Neural model number
 * @param NeuronNum  Neuron number
 * @param t          Current time t 
 *
 * @result Value of the input current of neuron NeuronNum in model ModelNum at time t
 ******************************************************************************/
extern double StepwiseInputCurrentWithNoise(Simul *Simulation, int ModelNum, int NeuronNum, double t);

#endif
