/*******************************************************************************
 * SiReNe software version 1.0
 * Copyright © 2018-2020, INRIA, CNRS, Université de Lorraine. All rights reserved.
 *
 * Authors : N. AZEVEDO CARVALHO, S. CONTASSOT-VIVIER, L. BUHRY and D. MARTINEZ
 * Version : 1.0
 * Years   : 2018-2020
 *
 * Authors : W. RAPHA, E. HUGUES, D. MARTINEZ and Y. BONIFACE
 * Version : 0.1
 * Years   : 2002-2009
 *
 * License : GNU General Public License, version 2
 *
 * This  program is  free  software; you  can  redistribute it  and/or
 * modify it  under the  terms of  the GNU  General Public  License as
 * published by the Free Software  Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT  ANY  WARRANTY;  without   even  the  implied  warranty  of
 * MERCHANTABILITY or FITNESS  FOR A PARTICULAR PURPOSE.   See the GNU
 * General Public License for more details.
 *
 ******************************************************************************/
/*!
 * @file 
 * @brief Numerical methods used to compute the network evolution at each time-step
 ******************************************************************************/

#ifndef NUMERICALMETHOD_H
#define NUMERICALMETHOD_H

#include "Sirene.h"

/*!*****************************************************************************
 * @brief Resolution of the ODE system by explicit Euler method
 *
 * @param Simulation Structure where all simulation information is stored
 * @param Update     Update function of each neuron in the models
 * @param TmpVar     Not used
 * @param TmpDer     Not used
 ******************************************************************************/
extern void Euler(Simul *Simulation, 
                  void (*Update)(Simul *Simulation, double tPrev, double t, double *Var, double *Der),
                  double *TmpVar, double *TmpDer);

/*!*****************************************************************************
 * @brief Resolution of the ODE system by the explicit Runge-Kutta 2 method
 *
 * @param Simulation Structure where all simulation information is stored
 * @param Update     Update function of each neuron in the models
 * @param TmpVar     Variables array for intermediate time-steps
 * @param TmpDer     Derivatives array for intermediate time-steps
 ******************************************************************************/
extern void RungeKutta2(Simul *Simulation, 
                        void (*Update)(Simul *Simulation, double tPrev, double t, double *Var, double *Der),
                        double *TmpVar, double *TmpDer);

#endif
