/*******************************************************************************
 * SiReNe software version 1.0
 * Copyright © 2018-2020, INRIA, CNRS, Université de Lorraine. All rights reserved.
 *
 * Authors : N. AZEVEDO CARVALHO, S. CONTASSOT-VIVIER, L. BUHRY and D. MARTINEZ
 * Version : 1.0
 * Years   : 2018-2020
 *
 * Authors : W. RAPHA, E. HUGUES, D. MARTINEZ and Y. BONIFACE
 * Version : 0.1
 * Years   : 2002-2009
 *
 * License : GNU General Public License, version 2
 *
 * This  program is  free  software; you  can  redistribute it  and/or
 * modify it  under the  terms of  the GNU  General Public  License as
 * published by the Free Software  Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT  ANY  WARRANTY;  without   even  the  implied  warranty  of
 * MERCHANTABILITY or FITNESS  FOR A PARTICULAR PURPOSE.   See the GNU
 * General Public License for more details.
 *
 ******************************************************************************/
/*!
 * @file 
 * @brief Synaptic current model.
 *
 * Synapse model:
 *   - Single exponential conductance:
 *     - "Spiking Neuron Models", Wulfram Gerstner and Werner M. Kistler,\n
 *       Cambridge University Press, 2002, pp 62-63 (2.4.2)
 ******************************************************************************/

#ifndef SYNAPTICCURRENT_H
#define SYNAPTICCURRENT_H

#include "Sirene.h"

/*!*****************************************************************************
 * @brief Synaptic current with exponential conductance at current time (t) from previous time (tPrev)
 *
 * @param Simulation        Structure where all simulation information is stored
 * @param ModelNum          Neural model number
 * @param NeuronNum         Neuron number
 * @param PreSynModel       Pre-synaptic neural model number
 * @param tPrev             Previous time from which the synaptic current is computed
 * @param t                 Current time at which the synaptic current is computed
 * @param CurrPostPotential Current post-potential
 *
 * @result Synaptic current
 ******************************************************************************/
extern double SynapticCurrent(Simul *Simulation, int ModelNum, int NeuronNum, int PreSynModel, double tPrev, double t, double CurrPostPotential);

/*!*****************************************************************************
 * @brief Update of synaptic current of a post-synatpic neuron after spike detection
 *
 * @param Simulation    Structure where all simulation information is stored
 * @param ModelNum      Neural model number
 * @param NeuronNum     Neuron number
 * @param PostSynModel  Post-synaptic neural model number
 * @param PostSynNeuron Post-synaptic neuron to update
 * @param SpikeTime     Spike time
 ******************************************************************************/
extern void SynapticSpike(Simul *Simulation, int ModelNum, int NeuronNum, int PostSynModel, int PostSynNeuron, double SpikeTime);

#endif
